#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Top-level package for xarray-fits."""

__author__ = """Alec Thomson"""
__email__ = 'alec.thomson@csiro.au'

from dafits.core import *